
function [B] = block_delete(B, opt)

%BLOCK_DELETE deletes the block and/or associated coordinate system
%             from figure window
% 
% syntax:
% [B] = block_delete(B)
% [B] = block_delete(B, opt)
%
% Function removes graphical representation of the block and/or block's 
% coordinate system from figure window.
%
% input:
% B   - handle to block to be deleted
% opt - determines deleted element, allowed values:
%       'all'   - deletes block and coordinate system
%       'block' - deletes only block
%       'csys'  - deletes only coordinate system
%       default value 'all'
%
% output:
% B - handle to a deleted block
%
% example:
%
% b = pyramid(2,1,1);
% block_plot(b)
% block_plot_csys(b)
% campos([-3,-3,1])
% pause
% block_delete(b)
% creates a new pyramid and plots block and associated coordinate system,
% after pressing any key graphical representation of the block and block's 
% coordinate system are removed
%
% See also: BLOCK, BLOCK_PLOT, BLOCK_PLOT_CSYS
%

global RTHND;

if ( nargin < 2 ) opt='all'; end

if ( ~parIsObj(B,'block') ) rethrow(geterr('argValObj', 'B', 'block')); end
if ( RTHND{B}.owner ~= 0  ) rethrow(geterr('argValObj0','B','block')); end
if ( ~parIsVectorTxt(opt) ) rethrow(geterr('argValTxt', 'opt')); end
if ( ~strcmpi(opt,'all') & ~strcmpi(opt,'block') & ~strcmpi(opt,'csys') ) 
  rethrow(geterr('argVal','opt','all, csys, robot')); 
end

fhnddel(B); 
blkdel(B, opt, 1);

if ( nargout == 0 ) clear B; end
