
function [B] = block_merge(B, varargin)

%BLOCK_MERGE combines given blocks
% 
% syntax:
% [B] = block_merge(B, ...)
%
% All blocks from the input argument list are attached to the first one
% and get all properties of this block. B containts all faces of the blocks 
% from the input argument list.The blocks which are combined stay as 
% indebendent objects. 
%
% input:
% B,... - a list of blocks to be merged
%
% output:
% B - handle to the first block in the input argument list
%
% example:
%
% b1 = cuboid(2,1,1,'BlockColor','b');
% b2 = pyramid(2,1,1,'BlockColor','r');
% b  = block_merge(b1, block_move(b2,[0;0;1]));
% block_plot(b)
% campos([-4,-3,3])
% creates and plots a new block composed of cuboid and pyramid on its top
%
% See also: BLOCK, BLOCK_COMPLEX
%

global RTHND;

if ( ~parIsObj(B,'block:basic') ) rethrow(geterr('argValObj', 'B', 'block:basic')); end
if ( RTHND{B}.owner ~= 0 ) rethrow(geterr('argValObj0','B','block:basic')); end

b = RTHND{B};
t = invt(b.T);

for i=1:length(varargin)

  BLK = varargin{i};
  blk = RTHND{BLK};
  if ( ~parIsObj(BLK,'block:basic') ) rethrow(geterr('argValObj','blocks','block')); end
  if ( RTHND{B}.owner ~= 0 ) rethrow(geterr('argValObj0','B','block:basic')); end

  blk.points = t * blk.T * blk.points;

  ls = length(b.faces);
  lp = size(b.points,2);

  b.points = [b.points blk.points];
  % b.edges  = [b.edges; blk.edges+lp];

  for j=1:length(blk.faces)
    b.faces{j+ls} = blk.faces{j}+lp;
  end
  
  %b.fig.handle = [b.fig.handle, blk.fig.handle];
  %b.csys.handle = [b.csys.handle, blk.csys.handle];

end

RTHND{B} = b;

if ( RTHND{B}.fig.axes ~= -1 )
  hold(RTHND{B}.fig.axes, 'on');
  B = blkrdrw(B,1);
  hold(RTHND{B}.fig.axes, 'off');
end

if ( nargout == 0 ) clear B; end
