
function [B] = block_plot(B, view)

%BLOCK_PLOT plots the block 
% 
% syntax:
% [B] = block_plot(B)
% [B] = block_plot(B, view)
%
% Parameters of the block are defined by its properties,
% see function 'block'.
%
% input:
% B    - handle to a block to be plotted
% view - method of plotting, allowed values:
%        'mesh' - block is plotted as a grid
%        'surf' - block is plotted as a set of patches
%        default value 'mesh'
%
% output:
% B - handle to a plotted block
%
% examples:
%
% b = block_plot(pyramid(2,1,1))
% campos([-3,-3,1])
% creates and plots a pyramid, it is plotted as a grid (default method)
%
% b = block_plot(pyramid(2,1,1), 'surf')
% campos([-3,-3,1])
% camlight
% creates and plots a pyramid, it is plotted as a set of patches
%
% See also: BLOCK, BLOCK_PLOT_CSYS, BLOCK_DELETE
%

global RTHND;

if ( nargin < 2 ) view = 1; end;

if ( ~parIsObj(B,'block') ) rethrow(geterr('argValObj', 'B', 'block')); end
if ( RTHND{B}.owner ~= 0  ) rethrow(geterr('argValObj0','B','block')); end
view = view2num(view, [1,2]);

if ( RTHND{B}.fig.axes == -1 ) RTHND{B}.fig.axes=getfigaxs(); fhndadd(B); end
hold(RTHND{B}.fig.axes, 'on');
B = blkplt(B, RTHND{B}.fig.axes, view);
hold(RTHND{B}.fig.axes, 'off');

if ( nargout == 0 ) clear B; end
