
function [B] = block_plot_csys(B)

%BLOCK_PLOT_CSYS plots the block's coordinate system
% 
% syntax:
% [B] = block_plot_csys(B)
%
% Parameters of the coordinate system are defined by properties of block,
% see function 'block'.
%
% input:
% B - handle to a block which coordinate system is to be plotted
%
% output:
% B - handle to a block witch coordinate system is to be plotted
%
% example:
% b = pyramid(2,1,1)
% block_plot(b)
% block_plot_csys(b)
% campos([-3,-3,1])
% creates a new pyramid and plots block and associated coordinate system
%
% See also: BLOCK, BLOCK_PLOT, BLOCK_DELETE
%

global RTHND;

if ( ~parIsObj(B,'block') ) rethrow(geterr('argValObj', 'B', 'block')); end
if ( RTHND{B}.owner ~= 0  ) rethrow(geterr('argValObj0','B','block')); end

if ( RTHND{B}.fig.axes == -1 ) RTHND{B}.fig.axes=getfigaxs(); fhndadd(B); end
hold(RTHND{B}.fig.axes, 'on');
B = blkpltcsys(B, RTHND{B}.fig.axes);
hold(RTHND{B}.fig.axes, 'off');

if ( nargout == 0 ) clear B; end
