
function [B] = block_set(B, varargin)

%BLOCK_SET sets the values of the block's properties
% 
% syntax:
% [B] = block_set(B, 'PropertyName', PropertyValue, ...)
% [B] = block_set(B, nr, 'PropertyName', PropertyValue, ...)
%
% input:
% B - handle to a block which properties is to be set
% property name/property value pairs are used to specify set properties,
% see function 'block'
%
% output:
% B - handle to a block which properties is to be seted
%
% example:
% b = pyramid(2,1,1)
% block_plot(b)
% campos([-3,-3,1])
% pause
% block_set(b, 'BlockColor', 'r')
% creates a new pyramid with default properties and after pressing any key 
% sets its color to red
%
% See also: BLOCK, BLOCK_GET, BLOCK_INFO
%

global RTHND;

if ( ~parIsObj(B,'block') ) rethrow(geterr('argValObj', 'B', 'block')); end

nr = 0;   b = B;
if ( isnumeric(varargin{1}) )
  if ( ~parIsObj(B,'block:complex') ) rethrow(geterr('argValObj', 'B', 'block:complex')); end
  nr = varargin{1};  
  if (( nr < 1 ) | ( nr > length(RTHND{B}.blocks) )) rethrow(geterr('argValObj1', 'nr')); end
  b = RTHND{B}.blocks(nr);
  varargin = varargin(2:length(varargin));
end

try   [lst, setlst] = prepopts(RTHND{b}.ident, varargin);
catch rethrow(lasterror); end;

switch( RTHND{b}.ident )
  case 'block:basic'
    for i=1:size(setlst,1) 
      RTHND{b} = blkset(RTHND{b}, setlst{i,1}, setlst{i,2}, setlst{i,4}, 0); 
    end
  case 'block:complex'
    for b=RTHND{b}.blocks  
      for i=1:size(setlst,1)
        RTHND{b} = blkset(RTHND{b}, setlst{i,1}, setlst{i,2}, setlst{i,4}, 0); 
      end
    end
end

b = B;
if ( RTHND{B}.owner ) b=RTHND{B}.owner; end
if ( RTHND{b}.fig.axes ~= -1 )
  hold(RTHND{b}.fig.axes, 'on');
  b = blkrdrw(b,1);
  hold(RTHND{b}.fig.axes, 'off');
end

if ( nargout == 0 ) clear B; end
