
function [CS] = csys_delete(CS)

%CSYS_DELETE deletes the coordinate system from figure window
% 
% syntax:
% [CS] = csys_delete(CS)
%
% Function removes graphical representation of the coordinate system
% from figure window.
%
% input:
% CS - handle to a coordinate system to be deleted
%
% output:
% CS - handle to a deleted coordinate system 
%
% example:
% axis([-3 3 -3 3 -3 3]);
% cs = csys(rotz(pi/4))
% csys_plot(cs)
% pause
% csys_delete(cs)
% creates and plots a coordinate system (origin located in (0,0,0) point, 
% rotated around z-axis by pi/4 radians), after pressing any key graphical 
% representation of the coordinate system is removed
%
% See also: CSYS, CSYS_PLOT
%

global RTHND;

if ( ~parIsObj(CS,'csys') ) rethrow(geterr('argValObj', 'CS', 'csys')); end

fhnddel(CS);
csdel(CS, 1);

if ( nargout == 0 ) clear CS; end
