
function [val] = csys_get(CS, name)

%CSYS_GET returns the value of the coordinate system's property
% 
% syntax:
% [val] = csys_get(CS, name)
%
% input:
% CS   - handle to a coordinate system which properties is to be get
% name - coordinate system's property name, see function 'csys'
%
% output:
% val - the value of the property specified by 'name'
%
% example:
% cs = csys(eye(4))
% c  = csys_get(cs, 'CSysColor')
% creates a new coordinate system and gets its color
%
% See also: CSYS, CSYS_INFO, CSYS_SET
%

global RTHND;

if ( ~parIsObj(CS,'csys') ) rethrow(geterr('argValObj', 'CS', 'csys')); end

try val=csget(CS, checkopt(RTHND{CS}.ident,name));
catch rethrow(lasterror); end;    
