
function [CS] = csys_plot(CS)

%CSYS_PLOT plots the coordinate system
% 
% syntax:
% [CS] = csys_plot(CS)
%
% Parameters of the coordinate system are defined by its properties,
% see function 'csys'.
%
% input:
% CS - handle to a coordinate system to be ploted
%
% output:
% CS - handle to a plotted coordinate system
%
% example:
% axis([-3 3 -3 3 -3 3]);
% cs = csys(rotz(pi/4), 'CSysColor', 'r')
% csys_plot(cs)
% creates and plots a coordinate system, its origin is located in (0,0,0) 
% point, system is rotated around z-axis by pi/4 radians
%
% See also: CSYS, CSYS_DELETE
%

global RTHND;

if ( ~parIsObj(CS,'csys') ) rethrow(geterr('argValObj', 'CS', 'csys')); end

if ( RTHND{CS}.fig.axes == -1 ) RTHND{CS}.fig.axes=getfigaxs(); fhndadd(CS); end
hold(RTHND{CS}.fig.axes, 'on');
CS = cspltobj(CS);
hold(RTHND{CS}.fig.axes, 'off');

if ( nargout == 0 ) clear CS; end
