
function [CS] = csys_set(CS, varargin)

%CSYS_SET sets the values of the coordinate system's properties
% 
% syntax:
% [CS] = csys_set(CS, 'PropertyName', PropertyValue, ...)
%
% input:
% CS - handle to a coordinate system which properties is to be set
% property name/property value pairs are used to specify fived properties,
% see function 'csys'
%
% output:
% CS - handle to a coordinate system which properties is to be seted 
%
% example:
% axis([-3 3 -3 3 -3 3]);
% cs = csys(eye(4))
% csys_plot(cs)
% pause
% csys_set(cs, 'CSysColor', 'r')
% creates a new coordinate system with default properties and after 
% pressing any key sets its color to red
%
% See also: CSYS, CSYS_GET, CSYS_INFO
%

global RTHND;

if ( ~parIsObj(CS,'csys') ) rethrow(geterr('argValObj', 'CS', 'csys')); end

try   [lst, setlst] = prepopts(RTHND{CS}.ident, varargin);
catch rethrow(lasterror); end;

cs = RTHND{CS};
for i=1:size(setlst,1)
  cs = csset(cs, setlst{i,1}, setlst{i,2}, setlst{i,4}, 0); 
end
RTHND{CS} = cs;

if ( cs.fig.axes ~= -1 )
  hold(cs.fig.axes, 'on');
  csrdrw(CS,1);
  hold(cs.fig.axes, 'off');
end

if ( nargout == 0 ) clear CS; end
