
function demo_multi

% ------------------------------------------------------------------------
% DEMO_TRJ
% Demo program of ROBOT toolbox
% RPR type manipulator moving block
% ------------------------------------------------------------------------

% manipulators and workspace definitions

t1 = [-pi/2;0.1;pi/2];
DH1 = [dh(0,0,0.25,t1(1)); dh(-pi/2,0,t1(2),0); dh(0,0,0.1,t1(3))];

r1 = robot(DH1, ['r', 'p', 'r'],...
           'RobotBase', [0.2;0;0],...
           'RobotGrasper', rp2t(roty(-pi/2),[0;0;0.15]),...
           'RobotGrasperSize', 0.1,...
           'RobotRange', [-pi, pi; 0, 0.4; -pi, pi],...
           'RobotCylinderRadius', 0.04,...
           'RobotCylinderApprox', 32,...
           'RobotColor', [0,0.25,0.65],...
           'RobotGrasperColor', [0,0.5,1],...
           'RobotExColor', 'g',...
           'RobotEdgeColor', 'none',... 
           'RobotModel', 'rangeex');
       
t2 =  [-pi/2; -3*pi/4; pi/2; pi/2; pi/2; 0];
DH2 = [dh(0,0,0,t2(1)); dh(-pi/2,0,0,t2(2)); dh(0,0.45,0,t2(3)); dh(-pi/2,0.45,0,t2(4)); dh(pi/2,0,0,t2(5)); dh(-pi/2,0,0,t2(6))];

r2 = robot(DH2, ['r', 'r', 'r', 'r', 'r', 'r'],...
           'RobotBase', [-0.25;0.5;0],...
           'RobotGrasper', [0.15;0;0],...
           'RobotGrasperSize', 0.1,...
           'RobotColor', [0.25, 0.45, 0.75],...
           'RobotExColor', [0, 0.65, 1],...
           'RobotEdgeColor', 'none',...
           'RobotCylinderRadius', 0.04,...
           'RobotCylinderApprox', 32,...
           'RobotModel', 'configex');
   
b1 = block_move(cuboid(0.03,0.03,0.2,'BlockColor','y','BlockEdgeColor',[0.75,0.75,0]),[0.8;0;0.15]);
f1 = block_merge(...
      block_move(cuboid(0.1,1,0.15,'BlockColor',[0.95,0.95,0.95],'BlockEdgeColor','k'),[0.8;0.25;0]),...
      block_move(cuboid(1.7,0.1,0.15,'BlockColor',[0.95,0.95,0.95],'BlockEdgeColor','k'),[0;0.8;0]),...
      block_move(cuboid(0.1,1,0.15,'BlockColor',[0.95,0.95,0.95],'BlockEdgeColor','k'),[-0.8;0.25;0]));
b2 = block_move(cuboid(0.03,0.03,0.2,'BlockColor','y','BlockEdgeColor',[0.75,0.75,0]),rp2t(rotx(pi/2),[-0.4;0.1;0.25]));
f2 = block_merge(...
      block_move(cuboid(0.03,0.03,0.235,'BlockColor','y','BlockEdgeColor',[0.75,0.75,0]),[-0.4; 0.085;0]),...
      block_move(cuboid(0.03,0.03,0.235,'BlockColor','y','BlockEdgeColor',[0.75,0.75,0]),[-0.4;-0.085;0]));

% manipulators and blocks in start position

clf
axis([-1 1 -1 1 0 2])
grid on
csys_plot(csys(eye(4), 'CSysAxisLength', axis));
camlight
robot_plot(r1, 'surf');  
robot_plot(r2, 'surf');  
block_plot(f1, 'surf');  block_plot(b1, 'surf');
block_plot(f2, 'surf');  block_plot(b2, 'surf');

% trajectories

t1_2 = [-pi/2; 0.3; pi/2];
t1_3 = [ pi/2-2*pi; 0.1; 0];
t1_4 = [ pi/2-2*pi; 0.3; 0];

q1 = [trajectory(1:80, t1, t1_2, 'poly3'), ...
     trajectory(1:80, t1_2, t1, 'poly3'), ...
     trajectory(1:120, t1, t1_3, 'poly3'), ...
     trajectory(1:80, t1_3, t1_4, 'poly3'), ...
     trajectory(1:80, t1_4, t1_3, 'poly3'), ...
     trajectory(1:120, t1_3, t1, 'poly3')];

t2_2 = [-pi/2; -3*pi/4; pi/2; pi; pi/2; 0];
t2_3 = [-1.8386; -1.3822; 1.3589; 2.8752; 1.5515; -0.0014];
t2_4 = [-2.1816; -1.1372; 1.4970; 2*pi;   2.7819;  2.1813];

q2 = [trajectory(1:40, t2, t2_2, 'poly3'), ...
      trajectory(1:80, t2_2, t2_3, 'poly3'), ...
      trajectory(1:80, t2_3, t2_4, 'poly3'), ...
      trajectory(1:160, t2_4, t2, 'poly3')];

t3_1 = [-0.8022; 0.0074; 0.1341];
t3_2 = [-0.8; 0.8;    0.15];
t3_3 = [0.8;  0.8;    0.15];
t3_4 = [0.8;  0;      0.15];

q3 = [trajectory(1:70,  t3_1, t3_2, 'poly3'), ...
      trajectory(1:120, t3_2, t3_3, 'poly3'), ...
      trajectory(1:70,  t3_3, t3_4, 'poly3')];

% animation  
      
h = text(-5,0,6,'Press any key...');
pause;  delete(h);
 
animation(1:560, r1, @fun1, r2, @fun2, b2, @fun3, 0, 0, q1, q2, q3, b1, b2)

end



function [conf] = fun1(r, t, flag, q1, q2, q3, b1, b2)
  conf = q1(:,min(t,size(q1,2)));
  switch (t)
    case 81,   robot_catch(r, b1);
    case 361,  robot_drop(r);
  end      
end

function [conf] = fun2(r, t, flag, q1, q2, q3, b1, b2)
  conf = q2(:,min(t,size(q2,2)));
  switch (t)
    case 121,  robot_catch(r, b2);      
    case 201,  robot_drop(r);
        global RTHND;
        RTHND{b2}.T
  end      
end

function [conf] = fun3(b, t, flag, q1, q2, q3, b1, b2)
  if (t<301) conf = [];
  else  conf = q3(:,min(t-300,size(q3,2))); 
  end
end
