
function [B] = polygon(r, n, varargin)

%POLYGON creates a regular polygon given by radius and number of sides
% 
% syntax:
% [B] = polygon(r, n)
% [B] = polygon(r, n, 'PropertyName', PropertyValue, ...)
%
% Polygon lies in xy-plane, point (0, 0, 0) is located in its center.
%
% input:
% r - a radius of the circumcircle of the polygon
% n - a number of sides
% property name/property value pairs are used to specify additional block
% properties, see function 'block'
%
% output:
% B - handle to a new block
%
% example:
% b = polygon(1, 10)
% block_plot(b)
% creates and plots a 10-sided polygon inscribed in a circle of radius 1, 
% all properties are default 
%
% See also: BLOCK, CONE, CUBE, CUBOID, CYLINDER, POLYLINE, PRISM, 
%           PYRAMID, SPHERE, TETRAHEDRON
%

p = dopolygon(r,n);

B = polyline([p p(:,1); zeros(1,n+1)], varargin{:});
