
function [B] = polyline(p, varargin)

%POLYLINE creates a polyline given by set of points
% 
% syntax:
% [B] = polyline(p)
% [B] = polyline(p, 'PropertyName', PropertyValue, ...)
%
% input:
% p - a column matrix containing the x, y, z coordinates for each point
% property name/property value pairs are used to specify additional block
% properties, see function 'block'
%
% output:
% B - handle to a new block
%
% example:
% b = polyline([[0;0;0] [1;1;0] [0;1;1]])
% block_plot(b)
% campos([-1,-4,3])
% creates and plots a polyline consisting of three points, 
% all properties are default 
%
% See also: BLOCK, CONE, CUBE, CUBOID, CYLINDER, POLYGON, PRISM, 
%           PYRAMID, SPHERE, TETRAHEDRON
%

f{1} = [1:size(p,2)-1; 2:size(p,2)]';

B = block(p, f, varargin{:});
