
function err = geterr(ident, varargin)

msg = 'Undefined error';

switch ( ident ) 
    
  case 'argNum',        msg = 'Invalid number of arguments';
  case 'argAllowed',    msg = 'Illegal value of argument "%s", allowed values: %s.';
  case 'argVal',        msg = 'Invalid value of argument "%s", allowed values: %s.';
  case 'argValCell',    msg = 'Invalid value of argument "%s", cell array expected.';
  case 'argValCellT',   msg = 'Invalid value of argument "%s", cell array with transformation operators expected.';
  case 'argValMtx',     msg = 'Invalid value of argument "%s", %dx%d matrix expected.';
  case 'argValMtx1',    msg = 'Invalid value of argument "%s", %d-row matrix expected.';
  case 'argValMtx2',    msg = 'Invalid value of argument "%s", %d-column matrix expected.';
  case 'argValNum',     msg = 'Invalid value of argument "%s", number expected.';
  case 'argValObj',     msg = 'Invalid value of argument "%s", object %s expected.';
  case 'argValObj0',    msg = 'Invalid value of argument "%s", independent object %s expected.';
  case 'argValObj1',    msg = 'Invalid value of argument "%s", index of component object has incorrect value.';
  case 'argValObj2',    msg = 'Invalid value of argument "%s", object expected.';
  case 'argValT',       msg = 'Invalid value of argument "%s", 4x4 transformation matrix expected.';
  case 'argValTxt',     msg = 'Invalid value of argument "%s", text expected.';
  case 'argValVect',    msg = 'Invalid value of argument "%s", %d-element vector expected.';
  case 'argValVect0',   msg = 'Invalid value of argument "%s", vector expected.';
  case 'argValCVect',   msg = 'Invalid value of argument "%s", column vector expected.';
  case 'argValRVect',   msg = 'Invalid value of argument "%s", row vector expected.';
  case 'argValVectTxt', msg = 'Invalid value of argument "%s", %d-element character array expected.';
  case 'argValFun',     msg = 'Invalid value of argument "%s", function expected.';
  case 'argValFun1',    msg = 'Error during calling %d. function, probably incorrect number of arguments.';
  case 'argRMtn',       msg = 'Missing trajectory.';
      
  case 'retValT',   msg = 'Invalid value returned by function describing trajectory of object "%d", trasformation operator expected.';
  case 'retValQ',   msg = 'Invalid value returned by function describing trajectory of robot "%d", configuration vector expected.';
  
  case 'trjMethod', msg = 'Incorrect name of method (%s).';
  case 'trjQLen',   msg = 'Incorrect dimensions of configurations vectors, sizes of "q0" and "qt" have to be equal.';
  case 'trjVLen',   msg = 'Incorrect dimensions of velocities vectors, sizes of "v0" and "vt" have to be equal to size of "q0".';
  case 'trjALen',   msg = 'Incorrect dimensions of accelerations vectors, sizes of "a0" and "at" have to be equal to size of "q0".';
  case 'trjAUndef', msg = 'Missing acceerations values.';
  case 'trjAZero',  msg = 'Accelerations cannot be equal to zero.';

  case 'prop',           msg = 'Name of property expected.';
  case 'propName',       msg = 'Incorrect name of property: "%s".';      
  case 'propVal',        msg = 'Incorrect value of property "%s", allowed values: %s.';
  case 'propValCellTxt', msg = 'Incorrect value of property "%s", %d-element cell array with text value expected.';
  case 'propValColor',   msg = 'Incorrect value of property "%s", name of color or 3-element vector expected.';
  case 'propValMtx',     msg = 'Incorrect value of property "%s", %dx%d matrix expected.';
  case 'propValMtx1',    msg = 'Incorrect value of property "%s", %d-row matrix expected.';
  case 'propValMtx2',    msg = 'Incorrect value of property "%s", %d-column matrix expected.';
  case 'propValNum',     msg = 'Incorrect value of property "%s", %number expected.';
  case 'propValRColor',  msg = 'Incorrect value of property "%s", color definition or %d-element cell array containing color definition expected.';
  case 'propValVect',    msg = 'Incorrect value of property "%s", %d-element vector expected.';
  case 'propValVect2',   msg = 'Incorrect value of property "%s", number or %d-element vector expected.';
  case 'propValTxt',     msg = 'Incorrect value of property "%s", text expected.';
      
  case 'colorName',    msg = 'Incorrect color name.';
  case 'colorDef',     msg = 'Incorrect color definition.';
  
end

err.identifier = ['ROBOT:', ident];
err.message    = sprintf(msg, varargin{:});
