
function [R] = rset(R, name, def, val, init)

global RTHND;

if ( strcmp(val,'_undef_') ) val=def; end

switch ( name )
      
  case 'RobotBase'

    if ( parIsMatrix(val,3,1) ) R.base=rp2t(eye(3), val);
    elseif ( parIsMatrix(val,3,3) ) R.base=rp2t(val, zeros(3,1));
    elseif ( parIsMatrix(val,4,4) ) R.base=val;
    else rethrow(geterr('propValMtx',name,4,4)); end
    
    switch ( R.ident )
      case 'robot:complex', if ( R.owner ) R=rrfrsh(R, 'RobotModel'); end
    end

  case 'RobotGrasper'

    if ( parIsMatrix(val,3,1) ) R.grasper=rp2t(eye(3), val);
    elseif ( parIsMatrix(val,3,3) ) R.grasper=rp2t(val, zeros(3,1));
    elseif ( parIsMatrix(val,4,4) ) R.grasper=val;
    else rethrow(geterr('propValMtx',name,4,4)); end
    if ( ~init ) R=rrfrsh(R, name); end
    
  case 'RobotGrasperSize'

    if ( parIsVector(val,1) ) R.grasperSize=[val, val];
    elseif ( parIsVector(val,2) ) R.grasperSize=val;
    else rethrow(geterr('propValVect',name,2)); end
    if ( ~init ) R=rrfrsh(R, name); end

  case 'RobotPlatformSize'

    if ( parIsVector(val,3) ) R.platformSize=val;
    else rethrow(geterr('propValVect',name,3)); end
    if ( ~init ) R=rrfrsh(R, name); end

  case 'RobotRange'
        
    if ( init & isempty(val) )
      val = [ -Inf*ones(R.n,1) Inf*ones(R.n,1) ];
    elseif (( ~init & isempty(val) ) | ~parIsMatrix(val,R.n,2) )
       rethrow(geterr('propValMtx',name,R.n,2));
    end
    
    cfg = 0;
    for i=1:R.n
      if ( val(i,1) > val(i,2) )
        v=val(i,2); val(i,2)=val(i,1); val(i,1)=v;
        warning('ROBOT:robotRange1', getwrn('robotRange1', i, val(i,1), val(i,2)))
      end
      if ( R.joints(i) == 'r' ) nr=4; else nr=3; end
      if ( R.dh(i,nr) < val(i,1) ) 
        R.dh(i,nr) = val(i,1);   cfg=1;
        warning('ROBOT:robotRange2', getwrn('robotRange2', i, R.dh(i,nr)))
      elseif( R.dh(i,nr) > val(i,2) )
        R.dh(i,nr) = val(i,2);   cfg=1;
        warning('ROBOT:robotRange2', getwrn('robotRange2', i, R.dh(i,nr)))
      end
    end
    
    R.range = val;

    if ( ~init ) 
      if (( strcmp(R.def3d.model,'range') | strcmp(R.def3d.model,'rangeex') ) & any(R.joints ~= 'r'))
        R = rrfrsh(R, name); 
      elseif (( strcmp(R.def3d.model,'config') | strcmp(R.def3d.model,'configex') ) & cfg )
        rcfgset(R.hnd,rcfgget(R.hnd,1));
      end
    end
    
  case 'RobotLineWidth',
      
    if ( parIsVector(val,1) ) R.plain.lineWidth = val;
    else rethrow(geterr('propValNum',name)); end

  case 'RobotColor',
    
    switch ( R.ident )
      case 'robot:complex'
        if ( iscell(val) )
          if ( length(val) ~= 2 ) rethrow(geterr('propValRColor',name,2)); 
          else val={val{1}, [], [], val{2}}; end
        else val = { val, [], [], val }; end
      case 'robot:manip'
        if ( iscell(val) )
          if ( length(val) ~= 4 ) rethrow(geterr('propValRColor',name,4)); end
        else val = { val, val, val, val }; end
      case 'robot:platform'
        if ( iscell(val) )
          if ( length(val) ~= 1 ) rethrow(geterr('propValRColor',name,1)); 
          else val={val, [], [], []}; end
        else val = { val, [], [], [] }; end
    end
    
    R.fig.color = val;
    if ( ~init ) R=rrfrsh(R, name); end

  case 'RobotLengthColor'
      
    if ( ~strcmp(val,'_undef_') ) 
      R.fig.color{1} = val;
      if ( ~init ) R=rrfrsh(R, name); end
    end

  case 'RobotOffsetColor'
      
    if ( ~strcmp(val,'_undef_') ) 
      R.fig.color{2} = val;
      if ( ~init ) R=rrfrsh(R, name); end
    end

  case 'RobotGrasperColor'
      
    if ( ~strcmp(val,'_undef_') ) 
      R.fig.color{3} = val; 
      if ( ~init ) R=rrfrsh(R, name); end
    end

  case 'RobotExColor'
      
    if ( ~strcmp(val,'_undef_') ) 
      R.fig.color{4} = val; 
      if ( ~init ) R=rrfrsh(R, name); end
    end

  case 'RobotEdgeColor',
      
    switch ( R.ident )
      case 'robot:complex'
        if ( iscell(val) )
          if ( length(val) ~= 2 ) rethrow(geterr('propValRColor',name,2));
          else val={val{1}, [], [], val{2}}; end
        else val={ val, [], [], val }; end
      case 'robot:manip'
        if ( iscell(val) )
          if ( length(val) ~= 4 ) rethrow(geterr('propValRColor',name,4)); end
        else val = { val, val, val, val }; end
      case 'robot:platform'
        if ( iscell(val) )
          if ( length(val) ~= 1 ) rethrow(geterr('propValRColor',name,1));
          else val={val, [], [], []}; end
        else val={ val, [], [], [] }; end
    end

    R.fig.edgeColor = val;
    if ( ~init ) R=rrfrsh(R, name); end

  case 'RobotLengthEdgeColor'
      
    if ( ~strcmp(val,'_undef_') ) 
      R.fig.edgeColor{1}=val; 
      if ( ~init ) R=rrfrsh(R, name); end
    end
  
  case 'RobotOffsetEdgeColor'
      
    if ( ~strcmp(val,'_undef_') ) 
      R.fig.edgeColor{2} = val; 
      if ( ~init ) R=rrfrsh(R, name); end
    end
  
  case 'RobotGrasperEdgeColor'
      
    if ( ~strcmp(val,'_undef_') ) 
      R.fig.edgeColor{3} = val;
      if ( ~init ) R=rrfrsh(R, name); end
    end

  case 'RobotExEdgeColor'
      
    if ( ~strcmp(val,'_undef_') ) 
      R.fig.edgeColor{4} = val;
      if ( ~init ) R=rrfrsh(R, name); end
    end

  case 'RobotEdgeWidth'
      
    if ( parIsVector(val,1) ) R.fig.edgeWidth=val;
    else rethrow(geterr('propValNum',name)); end
    if ( ~init ) R=rrfrsh(R, name); end

  case 'RobotCylinderRadius'
      
    if ( parIsVector(val,1) ) R.def3d.cylinderRadius = val;
    else rethrow(geterr('propValNum',name)); end
    if ( ~init ) R=rrfrsh(R, name); end

  case 'RobotCylinderApprox'
      
    if ( parIsVector(val,1) ) R.def3d.cylinderApprox = val;
    else rethrow(geterr('propValNum',name)); end
    if ( ~init ) R=rrfrsh(R, name); end

  case 'RobotModel'
      
    if ( ~parIsVectorTxt(val) ) rethrow(geterr('propValTxt',name));
    elseif ( ~parIsText(val,{'config','configex','range','rangeex'}) ) 
      rethrow(geterr('propVal',name,'config, configex, range, rangeex')); 
    end
    
    switch (R.ident)
      case 'robot:manip'
        if ( any(any(abs(R.range)==Inf)) ) 
          if ( strcmpi(val,'range') )
            val = 'config';
            warning('ROBOT:robotModel', getwrn('robotModel', 'range', 'config'))
          elseif ( strcmpi(val,'rangeex') )
            val = 'configex';
            warning('ROBOT:robotModel', getwrn('robotModel', 'rangeex', 'configex'))
          end
        end
    end
    
    R.def3d.model=lower(val);

    if ( ~init ) R=rrfrsh(R, name); end
    
  case 'CSysAxisLength'
      
    if ( isnumeric(val) )
      if     ( length(val) == 1 ) val = [0,abs(val),0,abs(val),0,abs(val)];
      elseif ( length(val) == 2 ) val = [val(1),val(2),val(1),val(2),val(1),val(2)];
      elseif ( length(val) == 3 ) val = [0,abs(val(1)),0,abs(val(2)),0,abs(val(3))];
      elseif ( length(val) == 6 ) val = val;
      else rethrow(geterr('propValVect2',name,'3,6')); end
      R.csys.axisLength = val;
    else rethrow(geterr('propValVect2',name,'3,6')); end

  case 'CSysColor'
      
    R.csys.color = val;
  
  case 'CSysWidth'
    if ( parIsVector(val,1) ) R.csys.width=val;
    else rethrow(geterr('propValNum',name)); end

  case 'CSysLabelColor'
      
    R.csys.labelColor = val;
  
  case 'CSysLabel'
      
    switch (R.ident)
        
      case 'robot:complex'
        if ( ischar(val)  ) val={val}; end
        if ( ~parIsCellTxt(val,1) ) rethrow(geterr('propValCellTxt',name,1)); end

        R.csys.label = val;

        if ( ~init )
          for j=1:3
            R.csys.axisLabels{1, j} = R.csys.axisLabel{j};
            if ( ~isempty(R.csys.axisLabel{j}) & ~isempty(R.csys.label{1}) ) 
              R.csys.axisLabels{1, j} = [R.csys.axisLabels{1, j}, '_', R.csys.label{1}];
            end
          end  
        end
        
      case 'robot:manip'
        if ( strcmp(val, '_undef_') ) 
          val = {'0'};
          for i=1:R.n val{i+1}=sprintf('%1d', i); end
          val{R.n+2} = 'G';
        elseif ( isempty(val) )
          for i=1:R.n+2 val{i}=''; end
        elseif ( ~parIsCellTxt(val,R.n+2) ) rethrow(geterr('propValCellTxt',name,R.n+2)); end

        R.csys.label = val;

        if ( ~init )
          for i=1:R.n+2
            for j=1:3
              R.csys.axisLabels{i, j} = R.csys.axisLabel{j};
              if ( ~isempty(R.csys.axisLabel{j}) & ~isempty(R.csys.label{i}) ) 
                R.csys.axisLabels{i, j} = [R.csys.axisLabels{i, j}, '_', R.csys.label{i}];
              end
            end  
          end
        end

      case 'robot:platform'
        if ( strcmp(val, '_undef_') ) val={'0', 'P'};
        elseif ( isempty(val) ) val={'', ''}; 
        elseif ( ~parIsCellTxt(val,2) ) rethrow(geterr('propValCellTxt',name,2)); end

        R.csys.label = val;

        if ( ~init )
          for i=1:2
            for j=1:3
              R.csys.axisLabels{i, j} = R.csys.axisLabel{j};
              if ( ~isempty(R.csys.axisLabel{j}) & ~isempty(R.csys.label{i}) ) 
                R.csys.axisLabels{i, j} = [R.csys.axisLabels{i, j}, '_', R.csys.label{i}];
              end
            end  
          end
        end
    end

  case 'CSysAxisLabel'
  
    if ( isempty(val) ) val = {'', '', ''}; 
    elseif ( ~parIsCellTxt(val,3) ) rethrow(geterr('propValCellTxt',name,3)); end

    R.csys.axisLabel = val;
    
    switch (R.ident)
        
      case 'robot:complex'
        for j=1:3
          R.csys.axisLabels{1, j} = val{j};
          if ( ~isempty(val{j}) & ~isempty(R.csys.label{1}) ) 
            R.csys.axisLabels{1, j} = [R.csys.axisLabels{1, j}, '_', R.csys.label{1}];
          end
        end  
        
      case 'robot:manip'
        for i=1:R.n+2
          for j=1:3
            R.csys.axisLabels{i, j} = val{j};
            if ( ~isempty(val{j}) & ~isempty(R.csys.label{i}) ) 
              R.csys.axisLabels{i, j} = [R.csys.axisLabels{i, j}, '_', R.csys.label{i}];
            end
          end  
        end

      case 'robot:platform'
        for i=1:2
          for j=1:3
            R.csys.axisLabels{i, j} = val{j};
            if ( ~isempty(val{j}) & ~isempty(R.csys.label{i}) ) 
              R.csys.axisLabels{i, j} = [R.csys.axisLabels{i, j}, '_', R.csys.label{i}];
            end
          end  
        end
    end
    
end
