
function [hnd,panels] = uitabcontrol(varargin)

backgroundcolor = get(0,'DefaultUipanelBackgroundColor');
foregroundcolor = get(0,'DefaultUipanelForegroundColor');
highlightcolor  = get(0,'DefaultUipanelHighlightColor');
shadowcolor     = get(0,'DefaultUipanelShadowColor');

tabcaptions        = {'tab1', 'tab2', 'tab3'};
tabbackgroundcolor = backgroundcolor;
tabforegroundcolor = foregroundcolor;
tabhighlightcolor  = highlightcolor;
tabshadowcolor     = shadowcolor;

proplst = {'BorderType','none', 'BorderWidth',0, 'ResizeFcn', @onResize};
for i=1:2:length(varargin)
  prop = lower(varargin{i});
  val  = varargin{i+1};
  save = 1;
  switch ( prop )
    % uipanel
    case 'backgroundcolor',    backgroundcolor    = val;
    case 'bordertype',         bordertype         = val;  save=0;
    case 'borderwidth',        borderwidth        = val;  save=0;
    case 'busyaction',         busyaction         = val;
    case 'buttondownfcn',      buttondownfcn      = val;
    case 'children',           children           = val;
    case 'clipping',           clipping           = val;
    case 'createfcn',          createfcn          = val;
    case 'deletefcn',          deletefcn          = val;
    case 'fontangle',          fontangle          = val;
    case 'fontname',           fontname           = val;
    case 'fontsize',           fontsize           = val;
    case 'fontunits',          fontunits          = val;
    case 'fontweight',         fontweight         = val;
    case 'foregroundcolor',    foregroundcolor    = val;
    case 'handlevisibility',   handlevisibility   = val;
    case 'highlightcolor',     highlightcolor     = val;
    case 'hittest',            hittest            = val;
    case 'interruptible',      interruptible      = val;
    case 'parent',             parent             = val;
    case 'position',           position           = val;
    case 'resizefcn',          resizefcn          = val;  save=0;
    case 'selected',           selected           = val;
    case 'selectionhighlight', selectionhighlight = val;
    case 'shadowcolor',        shadowcolor        = val;
    case 'tag',                tag                = val;
    case 'title',              title              = val;
    case 'titleposition',      titleposition      = val;
    case 'uiontextmenu',       uiontextmenu       = val;
    case 'units',              units              = val;
    case 'userdata',           userdata           = val;
    case 'visible',            visible            = val;
    %uitabcontrol
    case 'tabcaptions',        tabcaptions        = val;  save = 0;
    case 'tabbackgroundcolor', tabbackgroundcolor = val;  save = 0;
    case 'tabforegroundcolor', tabforegroundcolor = val;  save = 0;
    case 'tabhighlightcolor',  tabhighlightcolor  = val;  save = 0;
    case 'tabshadowcolor',     tabshadowcolor     = val;  save = 0;
    otherwise rethrow(sprintf('Invalid uitabcontrol property: %s',prop));
  end;
  if ( save ) proplst={proplst{:},prop,val}; end
end;  

if ~exist('bordertype','var')  bordertype='beveledout'; end
if ~exist('borderwidth','var') borderwidth=1; end
if ~exist('parent','var')      parent=gcf;              proplst={'Parent',parent,proplst{:}}; end
if ~exist('position','var')    position=[0,0,35,10];    proplst={proplst{:},'Position',position}; end
if ~exist('units','var')       units='character';       proplst={'Units',units,proplst{:}}; end

hnd = uipanel(proplst{:});

switch ( lower(bordertype) )
  case {'beveldin', 'beveledout'}
    tabborder  = borderwidth; 
    tabborder1 = tabborder;  
    tabborder2 = tabborder; 
  case {'etchedin', 'etcheout'}
    tabborder  = 2*borderwidth; 
    tabborder1 = tabborder;  
    tabborder2 = tabborder;
  case 'line' 
    tabborder  = borderwidth; 
    tabborder1 = round(2*borderwidth/3);
    tabborder2 = floor(2*borderwidth/3);
end

tabheight = 1.5;
taboffset = 2;
tabactive = 0;

[tabs, caps, panels, cover] = CreateTabs(hnd, tabcaptions);
SetTabs(hnd, tabs, caps, panels);
SetActiveTab(1);


% creates all parts of uitabcontrol

function [tabs,caps,pnls,cvr] = CreateTabs(hnd, captions)

for i=1:length(captions)
  tabs(i) =   uipanel('Parent', hnd,...
                      'BorderType', bordertype,...
                      'BorderWidth', borderwidth,...
                      'BackgroundColor', tabbackgroundcolor,...
                      'ForegroundColor', tabforegroundcolor,...
                      'HighlightColor', tabhighlightcolor,...
                      'ShadowColor', tabshadowcolor,...
                      'ButtonDownFcn', {@onButtonDown,i});
  caps(i) = uicontrol('Parent', tabs(i),...
                      'Style', 'Text',...
                      'String', captions{i},...
                      'HorizontalAlignment', 'center',...
                      'BackgroundColor', tabbackgroundcolor,...
                      'ForegroundColor', tabforegroundcolor,...
                      'Enable', 'inactive',...
                      'HitTest', 'off');
  ud.tabctrl.nr = i;
  ud.tabctrl.tab = tabs(i);
  ud.tabctrl.caption = captions{i};
  pnls(i) =   uipanel('Parent',hnd,...
                      'BorderType', bordertype,...
                      'BorderWidth', borderwidth,...
                      'BackgroundColor', tabbackgroundcolor,...
                      'ForegroundColor', tabforegroundcolor,...
                      'HighlightColor', tabhighlightcolor,...
                      'ShadowColor', tabshadowcolor,...
                      'UserData', ud,...
                      'Visible', 'off');
  if ( exist('resizefcn', 'var') ) set(pnls(i),'ResizeFcn',resizefcn); end
end

cvr = uicontrol('Parent', hnd,... 
                'Style', 'Text',...
                'BackgroundColor', tabbackgroundcolor,...
                'ForegroundColor', tabforegroundcolor,...
                'Enable', 'inactive',...
                'HitTest', 'off');
              
end                  
              

% sets size and position of all parts

function SetTabs(hnd, tabs, caps, pnls)

offset = 1;
set(hnd, 'Units','character');  pos = get(hnd, 'Position');
for i=1:length(tabs)
  set(caps(i), 'Units','character', 'Position',[0,0,1,1]);
  cap = get(caps(i),'String'); cap(strfind(cap,' ')) = '_';
  [cap,cp] = textwrap(caps(i),{cap});  cp(3) = cp(3)+2;
  set(tabs(i), 'Units','character', 'Position', [0,pos(4)-tabheight,cp(3),tabheight]);
  set(tabs(i), 'Units', 'pixels'); tp = get(tabs(i), 'Position');
  set(tabs(i), 'Position', [offset+taboffset,tp(2)-2*tabborder-taboffset,...
                            tp(3)+2*tabborder,tp(4)+2*tabborder]);
  set(caps(i), 'Units', 'pixels'); cp = get(caps(i), 'Position');
  set(caps(i), 'Position', [1,3,tp(3),cp(4)]);
  offset = offset+tp(3)+2*tabborder;
  set(pnls(i), 'Units','character', 'Position',[0,0,pos(3),pos(4)-tabheight]);
  set(pnls(i), 'Units','pixels');  p = get(pnls(i), 'Position');
  set(pnls(i), 'Position',[p(1:3),p(4)-tabborder-taboffset]);
end

end


% sets active panel

function SetActiveTab(idx)

if ( idx == 1 ) dx=taboffset; dw=taboffset+tabborder; dh=taboffset;
else  dx=tabborder; dw=2*tabborder; dh=taboffset; end
set(tabs(idx), 'Units', 'pixels'); tp = get(tabs(idx), 'Position');
set(tabs(idx), 'Position', [tp(1)-dx,tp(2),tp(3)+dw,tp(4)+dh]);
set(caps(idx), 'Units', 'pixels'); cp = get(caps(idx), 'Position');
set(caps(idx), 'Position', [cp(1:2),cp(3)+dw,cp(4)+dh]);
uistack(tabs(idx), 'top');
set(panels(idx), 'Visible', 'on');
uistack(panels(idx), 'top');
tp = get(tabs(idx), 'Position');
set(cover, 'Position', [tp(1)+tabborder1,tp(2),tp(3)-tabborder1-tabborder2,tabborder]);
uistack(cover, 'top');

if (( tabactive > 0 ) & ( idx ~= tabactive )) 
  if ( tabactive == 1 ) dx=taboffset; dw=taboffset+tabborder; dh=taboffset;
  else  dx=tabborder; dw=2*tabborder; dh=taboffset; end
  set(tabs(tabactive), 'Units', 'pixels'); tp = get(tabs(tabactive), 'Position');
  set(tabs(tabactive), 'Position', [tp(1)+dx,tp(2),tp(3)-dw,tp(4)-dh]);
  set(caps(tabactive), 'Units', 'pixels'); cp = get(caps(tabactive), 'Position');
  set(caps(tabactive), 'Position', [cp(1:2),cp(3)-dw,cp(4)-dh]);
  set(panels(tabactive), 'Visible', 'off');
end

tabactive = idx;

end


% events

function onButtonDown(hnd, data, idx)

if ( idx ~= tabactive ) SetActiveTab(idx); end

end


function onResize(hnd, data)

SetTabs(hnd, tabs, caps, panels);
SetActiveTab(tabactive);

end 


end
