
function [R]=robot_drop(R)

%ROBOT_DROP 'drops' a block catched by 'robot_catch', 
%           i.e. disconnects a block and a robot
% 
% syntax:
% [R] = robot_drop(R)
%
% input:
% R - handle to structure representing a robot holding a block
%
% output:
% R - handle to structure representing a robot without a block
%
% example:
% axis([-1 5 -1 5 -3 3]);
% campos([-1 -1 3]);
% camlight
% r = robot([dh(0,0,0,0)], ['r'], 'RobotCylinderRadius', 0.5, ...
%     'RobotGrasper', rp2t(rotx(pi/2),[3;0;0]), 'RobotGrasperSize', [1,2]);
% robot_plot(r, 'surf');
% b = block_move(cube(1,'BlockColor','g'),[4;0;-0.4]);
% block_plot(b,'surf');
% robot_catch(r,b);
% pause
% robot_motion(r,[0:0.05:pi/2]);
% robot_drop(r);
% pause
% robot_motion(r,[pi/2:-0.05:0]);
% creates a robot with one revolute joint and a cube which is catched by 
% robot, after pressing any key a robot moves a cube to new position and
% drops it there, after pressing any key robot returns to initial position
%
% See also: ROBOT, ROBOT_CATCH, ROBOT_CONFIG, ROBOT_MOTION
%

global RTHND;

if ( ~parIsObj(R,'robot:manip') ) rethrow(geterr('argValObj', 'R', 'robot:manip')); end

RTHND{RTHND{R}.cblock}.owner = 0;
RTHND{R}.cblock = 0;
RTHND{R}.tblock = [];
