
function robot_info(R, full)

%ROBOT_INFO displays all parameters of the robot
% 
% syntax:
% robot_info(R)
% robot_info(R, full)
%
% input:
% R    - handle to robot
% full - a flag determining if robot properties should be displayed
%
% examples:
%
% r = robot([dh(0,0,0,pi/2); dh(0,5,0,pi/2); dh(0,5,0,-pi/4)], ['r','r','r']);
% robot_info(r)
% creates a planar manipulator with three revolute kinematics pairs 
% and default properties, next displays its parameters
% 
% r1 = robot( [dh(0,0,0,-pi/2); dh(0,4,0,-pi/2); dh(0,3,0,-pi/2)], ['r', 'r', 'r'],...
%             'RobotBase', rp2t(rotx(-pi/2),[2;2;0]),...
%             'RobotGrasper', [2; 0; 0], 'RobotGrasperSize', 1);
% r2 = robot( [dh(0,0,0,-pi/4); dh(0,4,0,-pi/2); dh(0,3,0,-pi/4)], ['r', 'r', 'r'],...
%             'RobotBase', rp2t(rotx(-pi/2),[2;-2;0]),...
%             'RobotGrasper', [2; 0; 0], 'RobotGrasperSize', 1);
% r = robot_complex(r1, r2);
% r = robot([dh(0,0,0,pi/2); dh(0,5,0,pi/2); dh(0,5,0,-pi/4)], ['r','r','r']);
% robot_info(r,1)
% creates a complex robot consisting of two planar manipulators  with three 
% revolute kinematics pairs, next displays its parameters and properties
%
% See also: ROBOT, ROBOT_GET, ROBOT_SET
%

if ( ~parIsObj(R,'robot') ) rethrow(geterr('argValObj', 'R', 'robot')); end
if ( nargin < 2 ) full=0; end

rinfo(R, full);
