
function robot_panel(R)

%ROBOT_PANEL shows panel which allows to change configuration of the robot 
%            in figure window
% 
% syntax:
% robot_panel(R)
%
% The panel contains slider control for each robot joint. Limits of the
% sliders results from "RobotRange" property (see function Robot), if this
% property is undefined function takes following default values: -pi..pi
% for revolute joint and 0..10 for prismatic joint. Slider controls are
% placed inside a group box with caption corresponding to handle of the
% robot.
% In the case of connected mechanisms, defined by robot_complex and/or 
% robot_connect, each single component robot has its own group box with 
% sliders corresponding to its configuration variables. Group boxes are 
% arranged according to the structure of the mechanism. See example II.
%
% input:
% R - structure representing a robot
%
% examples:
%
% axis([-5 15 -10 10 -5 10])
% csys_plot(csys(eye(4), 'CSysAxisLength', axis));
% r = robot( [dh(0,0,0,-pi/4); dh(0,7,0,pi/2); dh(0,7,0,-pi/4)], ['r', 'r', 'r'],...
%     'RobotBase', rp2t(rotx(-pi/2),[0;0;0]), 'RobotGrasper', [3; 0; 0],...
%     'RobotRange', [-pi/2 0; -pi pi; -pi pi]);
% r = robot_plot(r, 'line');
% robot_panel(r)
% creates a robot with three revolute joints, plots a robot and shows a panel
% 
% axis([-3 7 -5 5 0 10]);
% view([-68,44])
% r1 = robot( [dh(0,0,0,-pi/2); dh(0,4,0,-pi/2)], ['r', 'r'],...
%             'RobotBase', rp2t(rotx(-pi/2),[2;2;0]), 'RobotColor', 'c', ...
%             'RobotGrasper', [2; 0; 0], 'RobotGrasperSize', 1);
% r2 = robot( [dh(0,0,0,-pi/4); dh(0,4,0,0)], ['r', 'r'],...
%             'RobotBase', rp2t(rotx(-pi/2),[2;-2;0]), 'RobotColor', 'r');
% r3 = robot( [dh(0,0,0,-pi/4)], ['r'], 'RobotBase', [0;0;-1], ...
%             'RobotGrasper', [2;0;0], 'RobotColor', 'g');  
% r4 = robot( [dh(0,0,0,-pi/4)], ['r'], 'RobotBase', [0;0;1], ...
%             'RobotGrasper', [2;0;0], 'RobotColor', 'm'); 
% robot_connect(r2, r3, r4);
% r = robot_complex(r2, r1);
% robot_plot(r)
% robot_panel(r)
% creates two planar manipulators with two revolute joints (r1 - cyan, 
% r2 - red), next creates two planar manipulators with one revolute joint 
% (r3 - green, r4 - magenta); r3 and r4 are attached to the robot r2; 
% r1 and r2 are connected into the one mechanism r; next plots the robot
% and shows its panel; r is a robot_complex containing r2 and r1 (r2 has
% been given as the first), moreover r3 and r4 have been attached to r2, so
% the panel contains four group boxes: first for r2, second for r3, third
% for r4 and the last for r1
%
% See also: ROBOT, ROBOT_PLOT
%

global RTHND;

if ( ~parIsObj(R,'robot') ) rethrow(geterr('argValObj', 'R', 'robot')); end
if ( RTHND{R}.owner  & parIsObj(RTHND{R}.owner,'robot') )
  rethrow(geterr('argValObj0','R','robot')); 
end

% RTHND{R}.panel

if ( ~RTHND{R}.panel ) rpnl('init', R, figure);
else figure(getfig(RTHND{R}.panel)); end

