
function [B] = srevolution(p, angle, varargin)

%SREVOLUTION creates a block obtained by rotating a polyline around Z-axis
% 
% syntax:
% [B] = srevolution(p, angle)
% [B] = srevolution(p, angle, n)
% [B] = srevolution(..., 'PropertyName', PropertyValue, ...)
%
% input:
% p     - a column matrix containing the x, z coordinates for each 
%         polyline point
% angle - number or vector, determining the tevolution angle 
%         if parameter is a vector its succesive elemens define 
%         approximation of  the solid
% n     - number, determining approximation of the solid, if angle is a 
%         vector is ommited
%         default 16
% property name/property value pairs are used to specify additional block
% properties, see function 'block'
%
% output:
% B - handle to a new block
%
% example:
%
% p = [ arc([2;0],[2;1],0.5), arc([2;1],[2;0],0.5) ];
% b = srevolution(p, 2*pi, 25);
% block_plot(b)
% campos([11,-5,7])
% creates and plots a torus with default properties 
%
% See also: BLOCK
%

if ( ~parIsMatrix(p,2,0) ) rethrow(geterr('argValMtx1','p',2)); end
if ( ~isnumeric(angle)   ) rethrow(geterr('argValVect0','angle')); end

if (( length(varargin) > 0 ) & isnumeric(varargin{1}) )
  n = varargin{1};
  varargin = varargin(2:length(varargin));
else n = 16; end


if ( length(angle) == 1 ) angle=linspace(0,angle,n); end
close = 0;
if ( abs(angle(length(angle))-angle(1)) == 2*pi ) 
  close = 1;
  angle = angle(1:length(angle)-1);
end

pt = [p(1,:)*cos(angle(1)); p(1,:)*sin(angle(1)); p(2,:)];   
n  = length(p);  nr = 1;  f = {};
for a=angle(2:length(angle))
  pt = [pt [p(1,:)*cos(a); p(1,:)*sin(a); p(2,:)]];
  for i=0:n-2  f = { f{:} [nr+i nr+i+1 nr+i+1+n nr+i+n] }; end
  nr = nr+n;
end

if ( close )
  nr = size(pt,2)-n+1;
  for i=0:n-2  f = { f{:} [nr+i nr+i+1 i+2 i+1] }; end
end;

B = block([pt; ones(1,size(pt,2))], f, varargin{:});
